@@ -102,7 +102,7 @@ class Command(BaseCommand):
                 url_path = entryCfg['url_path']
                 r = Model.objects.values_list(entryCfg['field'], flat=True)
                 for e in r:
-                    url = domain + '/' + url_path + str(e)
+                    url = domain + '/' + url_path + '/' + str(e)
                     self.write_sitemap_url(f, url, priority)
                     count += 1
             else:
@@ -159,11 +159,12 @@ class Command(BaseCommand):
             sitemapF = self.open_sitemap(filepath)
             for entryCfg in entry_data:
                 priority = self.get_priority(entryCfg)
-                count = self.write_urls(sitemapF, entryCfg, domain, priority)
+                count = count + self.write_urls(sitemapF, entryCfg, domain, priority)
             self.close_sitemap(sitemapF)
             
             if (options['verbosity'] > 0):
                 print(f"sitemap:{filepath}, count:{count}" )
+            count = 0
             
             # update index
             self.write_index_url(indexF, domain, mapname)
